@@ -40,7 +40,9 @@ def add_admin_handler(config, db_session, models=None, route_name_prefix='',
         The database session object
 
     :param models:
-        List of models for to include in the admin panel. get_models funcion can be used to include all models.
+        Note: For backward compatibility this parameter can either be a list (old) or a dictionary (new).
+        List/Dictionary of models for to include in the admin panel.
+        get_models funcion can be used to include all models.
 
     :param route_name_prefix:
         Optional string prefix to add to all route names generated inside the admin panel.
@@ -69,9 +71,19 @@ def add_admin_handler(config, db_session, models=None, route_name_prefix='',
 
     handler_class.db_session = db_session
     handler_class.models = models
-    for model in models:
-        tablename = model.__tablename__
-        handler_class.table_models[tablename] = model
+    all_models = []
+
+    if dict == type(models):
+        for appname, app_models in models.iteritems():
+            for model in app_models:
+                all_models.append(model)
+                tablename = model.__tablename__
+                handler_class.table_models[tablename] = model
+    else:
+        all_models = models
+        for model in models:
+            tablename = model.__tablename__
+            handler_class.table_models[tablename] = model
 
     handler_class.route_prefix = route_name_prefix
 
@@ -80,13 +92,14 @@ def add_admin_handler(config, db_session, models=None, route_name_prefix='',
                        handler=handler_class,
                        action='index')
 
-    if models:
-        for model in models:
+    if all_models:
+        for model in all_models:
             # TODO: Do model_field_args processing here.
 
             add_edit_field_args = {}
             list_field_args = {}
             FK_cols = get_columns(model, 'foreign_key')
+
             for FK in FK_cols:
                 db_col = list(FK.foreign_keys)[0].column.name
                 display_col = db_col
@@ -158,7 +171,7 @@ class AdminController(object):
 
     """
 
-    models = []
+    models = None
     table_models = {}
     db_session = None
     route_prefix = ''
